@@ -1,10 +1,16 @@
 # config.py
 
+import platform
+
+
 class Config:
     def __init__(self):
         self.cfg = None
         self.desc = []
-        self.path = "".join([_ + "\\" for _ in __file__.split("\\")][:-1]) + "data\\.config"
+        if platform.system() == "windows":
+            self.path = "".join([_ + "\\" for _ in __file__.split("\\")][:-1]) + "data\\.config"
+        else:
+            self.path = "".join([_ + "/" for _ in __file__.split("/")][:-1]) + "data/.config"
         self.load_cfg()
 
     def __getitem__(self, item):
